Class: SdrViewComponents::Structure::StyleOverrideLightComponent
- Inherits:
-
BaseComponent
- Object
- ViewComponent::Base
- BaseComponent
- SdrViewComponents::Structure::StyleOverrideLightComponent
- Defined in:
- app/components/sdr_view_components/structure/style_override_light_component.rb
Overview
Component for providing style overrides for light variant header. Switches the identity bar styling to the cardinal red background and white text.
Method Summary
Methods inherited from BaseComponent
#args_for, #mark_label_required, #merge_actions, #merge_classes