Class: SdrViewComponents::Structure::StyleOverrideLightComponent

Inherits:
BaseComponent
  • Object
show all
Defined in:
app/components/sdr_view_components/structure/style_override_light_component.rb

Overview

Component for providing style overrides for light variant header. Switches the identity bar styling to the cardinal red background and white text.

Method Summary

Methods inherited from BaseComponent

#args_for, #merge_actions, #merge_classes